@@ -1,6 +1,5 @@
 import os
-import subprocess
-import sys
+import argparse
 
 import blah.repositories
 import blah.fetcher
@@ -23,9 +22,10 @@ class FetchCommand(object):
     def create_parser(self, subparser):
         subparser.add_argument("repository_uri", metavar="repository-uri")
         subparser.add_argument("local_path", metavar="local-path")
+        subparser.add_argument("--use-cache", default=False, help=argparse.SUPPRESS, action="store_true")
     
     def execute(self, args):
-        blah.fetcher.fetch(args.repository_uri, args.local_path)
+        blah.fetcher.fetch(args.repository_uri, args.local_path, args.use_cache)
 
 commands = {
     "whatisthis": what_is_this_command,
